Coverage report

# Coverage report: 29%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 299 | 213 | 0 | 29%
src/FADiff.py | 32 | 14 | 0 | 56%
src/FuncVect.py | 41 | 32 | 0 | 22%
src/fad/Gradients.py | 66 | 53 | 0 | 20%
src/fad/Matrices.py | 52 | 40 | 0 | 23%
src/rev/Gradients.py | 83 | 68 | 0 | 18%
src/rev/Matrices.py | 18 | 6 | 0 | 67%
src/test_main.py | 7 | 0 | 0 | 100%

No items found using the specified filter.